from django.conf import settings
import fanout

if hasattr(settings, 'FANOUT_REALM'):
	fanout.realm = settings.FANOUT_REALM
if hasattr(settings, 'FANOUT_KEY'):
	fanout.key = settings.FANOUT_KEY

def publish(channel, data, id=None, prev_id=None, blocking=False, callback=None):
	if blocking:
		fanout.publish(channel, data, id, prev_id)
	else:
		fanout.publish_async(channel, data, id, prev_id, callback)



#!/usr/bin/env python

from setuptools import setup

setup(
name='django-fanout',
version='1.0.0',
description='Fanout.io library for Django',
author='Justin Karneges',
author_email='justin@fanout.io',
url='https://github.com/fanout/django-fanout',
license='MIT',
py_modules=['django_fanout'],
install_requires=['pyfanout>=1.0.0'],
classifiers=[
	'Topic :: Utilities',
	'License :: OSI Approved :: MIT License'
]
)
